import { ViewBase } from '../../libappbase/viewbase';
import { UIWaitSOP } from '../../libappsop/objectsop';
import { AppMP } from '../appmp';
import { FormProductPlanning } from '../forms/form.productplanning';
import { FormCapacityPlanning } from '../forms/form.capacityplanning';
import { FormSupplyPlanning } from '../forms/form.supplyplanning';

/**
 * Plan > Supply Planning view which shows PISPIP and entities' capacity planning information.
 */
export class ViewSupplyPlanning extends ViewBase implements UIWaitSOP {
  public readonly name = 'Supply planning';
  public readonly viewPath = 'Plan > Supply Planning';

  public frmProductPlanning = new FormProductPlanning();
  public formSupplyPlanning = new FormSupplyPlanning();
  public frmCapacityPlanning = new FormCapacityPlanning();

  public async switchTo(): Promise<void> {
    const appMP = AppMP.getInstance();

    await appMP.abpPlan.click();
    await appMP.abpPlan.btnSupplyPlanning.click();

    await this.waitUILoaded();
  }

  public async waitUILoaded(): Promise<void> {
    await this.frmProductPlanning.waitUntilPresent();
    await this.formSupplyPlanning.waitUntilPresent();
    await this.frmCapacityPlanning.waitUntilPresent();
  }
}
